#!/usr/local/bin/perl

my ($basedir) = ($0 =~ /(.*)\/.*/);

#
# Global definitions
#

# Enter the path to your data directory here
my $base = "";

# length of the sampling period, in seconds (300 = 5 minutes)
my $sample = 300;

# How often to sample, in seconds (5 = 1 ping every 5 seconds)
my $freq = 5;

# Chect for the right number of parameters
my $args=$#ARGV+1;
if($args < 1) { 
    die "Sorry, no target host specified.\nUsage: $0 dst_hostname\n"; 
} elsif ($args > 2) {
    die "Too many arguments.\nUsage: $0 dst_hostname\n";
}

# Arg is a hostname, do a gethostbyname lookup
my $target=$ARGV[0];
$target =~ tr/A-Z/a-z/;  # force to lowercase everything 
die "No such host: $target\n" unless defined(gethostbyname($target));

# Check if the directory to put the output exists
if( !(-e "$base/$target")) {
    die "Could not create directory $base/$target" 
	unless mkdir("$base/$target", oct("0755"));
} else {
    die "$base/$target is not a directory.\n" unless (-d "$base/$target");
}

my ($line, $tail, $tailtail);
my $numpings = int($sample/$freq);

# Do the ping, wait for the last line.
open(PING, "/usr/sbin/ping -I $freq -s $target 64 $numpings|");
while(defined($line = <PING>)){
    $tailtail = $tail;
    $tail = $line;
}
close(PING);
chomp($tailtail);
chomp($tail);

my ($xmit, $recv, $minimum, $avg, $max);

# Check to see if *any* pings got through.  If none did, replace the last 
# line with one that has all zeros.
if (($tail =~ m-min/avg/max = \d+/\d+/\d+-)) {
    ($xmit, $recv) = 
	($tailtail =~ m/(\d+) packets transmitted, (\d+) packets received/);
    ($minimum, $avg, $max) =  ($tail =~ m/(\d+)\/(\d+)\/(\d+)/);
} else {
    ($xmit, $recv) = ($tail =~ /(\d+) packets transmitted, (\d+) packets received/);
    $minimum = 0;
    $avg = 0;
    $max = 0;
}

my $loss = $xmit - $recv;

# If the log file does not exist, create it.
if (!(-e "$base/$target/delay.log")) {
    system("/usr/bin/touch $base/$target/delay.log");
}

# Dump the last line from the ping to the file.
open(OUT, ">>$base/$target/delay.log");
print OUT "$time: Xmit $xmit, Loss $loss, min/avg/max = $minimum/$avg/$max\n";
close(OUT);

open(OUT, ">$base/$target/delay.current");
print OUT "$time\n$xmit\n$loss\n$minimum\n$avg\n$max";
close(OUT);

# Done! exit cleanly.
exit 0;
